@@ -8,18 +8,22 @@
 // <int>.<int>.<int>-<any text>.
 // or else upgrading old project file will not work
 // reliably.
-#define VERSION "3.4.3-Madeira"
+// TODO QGIS 4: remove in favor of _QGIS_VERSION
+#define VERSION "3.12.1-București"
+#define _QGIS_VERSION "3.12.1-București"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 343
-#define VERSION_INT 30403
-#define ABISYM(x) x ## 30403
+//#define VERSION_INT 3121
+// TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
+#define VERSION_INT 31201
+#define _QGIS_VERSION_INT 31201
+#define ABISYM(x) x ## 31201
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Madeira"
+#define RELEASE_NAME "București"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -27,11 +31,11 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.4.3"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.12.1"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
-#define QSCINTILLA_VERSION_STR "2.10.8"
+#define QSCINTILLA_VERSION_STR "2.11.4"
 
 #if defined( __APPLE__ )
 //used by Mac to find system or bundle resources relative to amount of bundling
@@ -69,5 +73,9 @@
 
 /* #undef HAVE_QUICK */
 
+#define HAVE_QT5SERIALPORT
+
+/* #undef HAVE_STATIC_PROVIDERS */
+
 #endif
 
