@@ -21,10 +21,6 @@ __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
-
 import codecs
 import sys
 import operator
@@ -80,14 +76,19 @@ from qgis.core import (Qgis,
                        QgsProcessingUtils,
                        QgsProcessingModelAlgorithm,
                        QgsProcessingModelParameter,
-                       QgsProcessingParameterType
+                       QgsProcessingParameterType,
+                       QgsExpressionContextScope,
+                       QgsExpressionContext
                        )
 from qgis.gui import (QgsMessageBar,
                       QgsDockWidget,
                       QgsScrollArea,
                       QgsFilterLineEdit,
                       QgsProcessingToolboxTreeView,
-                      QgsProcessingToolboxProxyModel)
+                      QgsProcessingToolboxProxyModel,
+                      QgsProcessingParameterDefinitionDialog,
+                      QgsVariableEditorWidget,
+                      QgsProcessingParameterWidgetContext)
 from processing.gui.HelpEditionDialog import HelpEditionDialog
 from processing.gui.AlgorithmDialog import AlgorithmDialog
 from processing.modeler.ModelerParameterDefinitionDialog import ModelerParameterDefinitionDialog
@@ -97,6 +98,7 @@ from processing.modeler.ModelerScene import ModelerScene
 from processing.modeler.ProjectProvider import PROJECT_PROVIDER_ID
 from processing.script.ScriptEditorDialog import ScriptEditorDialog
 from processing.core.ProcessingConfig import ProcessingConfig
+from processing.tools.dataobjects import createContext
 from qgis.utils import iface
 
 
@@ -142,6 +144,8 @@ class ModelerDialog(BASE, WIDGET):
 
         self.setupUi(self)
 
+        self._variables_scope = None
+
         # LOTS of bug reports when we include the dock creation in the UI file
         # see e.g. #16428, #19068
         # So just roll it all by hand......!
@@ -183,8 +187,7 @@ class ModelerDialog(BASE, WIDGET):
         self.scrollArea_1.setWidget(self.scrollAreaWidgetContents_1)
         self.verticalDockLayout_1.addWidget(self.scrollArea_1)
         self.propertiesDock.setWidget(propertiesDockContents)
-        self.addDockWidget(Qt.DockWidgetArea(1), self.propertiesDock)
-        self.propertiesDock.setWindowTitle(self.tr("Model properties"))
+        self.propertiesDock.setWindowTitle(self.tr("Model Properties"))
 
         self.inputsDock = QgsDockWidget(self)
         self.inputsDock.setFeatures(QDockWidget.DockWidgetFloatable | QDockWidget.DockWidgetMovable)
@@ -245,6 +248,22 @@ class ModelerDialog(BASE, WIDGET):
         self.searchBox.setToolTip(self.tr("Enter algorithm name to filter list"))
         self.searchBox.setShowSearchIcon(True)
 
+        self.variables_dock = QgsDockWidget(self)
+        self.variables_dock.setFeatures(QDockWidget.DockWidgetFloatable | QDockWidget.DockWidgetMovable)
+        self.variables_dock.setObjectName("variablesDock")
+        self.variables_dock_contents = QWidget()
+        vl_v = QVBoxLayout()
+        vl_v.setContentsMargins(0, 0, 0, 0)
+        self.variables_editor = QgsVariableEditorWidget()
+        vl_v.addWidget(self.variables_editor)
+        self.variables_dock_contents.setLayout(vl_v)
+        self.variables_dock.setWidget(self.variables_dock_contents)
+        self.addDockWidget(Qt.DockWidgetArea(1), self.variables_dock)
+        self.variables_dock.setWindowTitle(self.tr("Variables"))
+        self.addDockWidget(Qt.DockWidgetArea(1), self.propertiesDock)
+        self.tabifyDockWidget(self.propertiesDock, self.variables_dock)
+        self.variables_editor.scopeChanged.connect(self.variables_changed)
+
         self.bar = QgsMessageBar()
         self.bar.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed)
         self.centralWidget().layout().insertWidget(0, self.bar)
@@ -262,6 +281,7 @@ class ModelerDialog(BASE, WIDGET):
         self.toolbutton_export_to_script.setPopupMode(QToolButton.InstantPopup)
         self.export_to_script_algorithm_action = QAction(QCoreApplication.translate('ModelerDialog', 'Export as Script Algorithm…'))
         self.toolbutton_export_to_script.addActions([self.export_to_script_algorithm_action])
+        self.toolbutton_export_to_script.setDefaultAction(self.export_to_script_algorithm_action)
         self.mToolbar.insertWidget(self.mActionExportImage, self.toolbutton_export_to_script)
         self.export_to_script_algorithm_action.triggered.connect(self.export_as_script_algorithm)
 
@@ -466,6 +486,7 @@ class ModelerDialog(BASE, WIDGET):
         else:
             self.model = QgsProcessingModelAlgorithm()
             self.model.setProvider(QgsApplication.processingRegistry().providerById('model'))
+        self.update_variables_gui()
 
         self.fillInputsTree()
 
@@ -503,6 +524,18 @@ class ModelerDialog(BASE, WIDGET):
             self.model.setHelpContent(dlg.descriptions)
             self.hasChanged = True
 
+    def update_variables_gui(self):
+        variables_scope = QgsExpressionContextScope(self.tr('Model Variables'))
+        for k, v in self.model.variables().items():
+            variables_scope.setVariable(k, v)
+        variables_context = QgsExpressionContext()
+        variables_context.appendScope(variables_scope)
+        self.variables_editor.setContext(variables_context)
+        self.variables_editor.setEditableScopeIndex(0)
+
+    def variables_changed(self):
+        self.model.setVariables(self.variables_editor.variablesInActiveScope())
+
     def runModel(self):
         if len(self.model.childAlgorithms()) == 0:
             self.bar.pushMessage("", self.tr("Model doesn't contain any algorithm and/or parameter and can't be executed"), level=Qgis.Warning, duration=5)
@@ -734,6 +767,8 @@ class ModelerDialog(BASE, WIDGET):
             self.textName.setText(alg.name())
             self.repaintModel()
 
+            self.update_variables_gui()
+
             self.view.centerOn(0, 0)
             self.hasChanged = False
         else:
@@ -756,18 +791,59 @@ class ModelerDialog(BASE, WIDGET):
         param = item.data(0, Qt.UserRole)
         self.addInputOfType(param)
 
+    def create_widget_context(self):
+        """
+        Returns a new widget context for use in the model editor
+        """
+        widget_context = QgsProcessingParameterWidgetContext()
+        widget_context.setProject(QgsProject.instance())
+        if iface is not None:
+            widget_context.setMapCanvas(iface.mapCanvas())
+        widget_context.setModel(self.model)
+        return widget_context
+
+    def autogenerate_parameter_name(self, parameter):
+        """
+        Automatically generates and sets a new parameter's name, based on the parameter's
+        description and ensuring that it is unique for the model.
+        """
+        validChars = \
+            'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'
+        safeName = ''.join(c for c in parameter.description() if c in validChars)
+        name = safeName.lower()
+        i = 2
+        while self.model.parameterDefinition(name):
+            name = safeName.lower() + str(i)
+            i += 1
+        parameter.setName(safeName)
+
     def addInputOfType(self, paramType, pos=None):
-        dlg = ModelerParameterDefinitionDialog(self.model, paramType)
-        dlg.exec_()
-        if dlg.param is not None:
+        new_param = None
+        if ModelerParameterDefinitionDialog.use_legacy_dialog(paramType=paramType):
+            dlg = ModelerParameterDefinitionDialog(self.model, paramType)
+            if dlg.exec_():
+                new_param = dlg.param
+        else:
+            # yay, use new API!
+            context = createContext()
+            widget_context = self.create_widget_context()
+            dlg = QgsProcessingParameterDefinitionDialog(type=paramType,
+                                                         context=context,
+                                                         widgetContext=widget_context,
+                                                         algorithm=self.model)
+            if dlg.exec_():
+                new_param = dlg.createParameter()
+                self.autogenerate_parameter_name(new_param)
+
+        if new_param is not None:
             if pos is None:
                 pos = self.getPositionForParameterItem()
             if isinstance(pos, QPoint):
                 pos = QPointF(pos)
-            component = QgsProcessingModelParameter(dlg.param.name())
-            component.setDescription(dlg.param.name())
+            component = QgsProcessingModelParameter(new_param.name())
+            component.setDescription(new_param.name())
             component.setPosition(pos)
-            self.model.addModelParameter(dlg.param, component)
+            self.model.addModelParameter(new_param, component)
             self.repaintModel()
             # self.view.ensureVisible(self.scene.getLastParameterItem())
             self.hasChanged = True
