@@ -21,10 +21,6 @@ __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
-
 import webbrowser
 
 from qgis.PyQt.QtCore import (Qt,
@@ -36,6 +32,7 @@ from qgis.PyQt.QtWidgets import (QDialog, QDialogButtonBox, QLabel, QLineEdit,
                                  QHBoxLayout, QWidget)
 
 from qgis.core import (Qgis,
+                       QgsProject,
                        QgsProcessingParameterDefinition,
                        QgsProcessingParameterPoint,
                        QgsProcessingParameterExtent,
@@ -142,6 +139,7 @@ class ModelerParametersDialog(QDialog):
         self.verticalLayout.addWidget(line)
 
         widget_context = QgsProcessingParameterWidgetContext()
+        widget_context.setProject(QgsProject.instance())
         if iface is not None:
             widget_context.setMapCanvas(iface.mapCanvas())
         widget_context.setModel(self.model)
@@ -151,9 +149,9 @@ class ModelerParametersDialog(QDialog):
         if self.algorithmItem:
             self.algorithmItem.setWidgetContext(widget_context)
             self.algorithmItem.registerProcessingContextGenerator(self.context_generator)
-        if self.configuration:
-            self.algorithmItem.setConfiguration(self.configuration)
-        self.verticalLayout.addWidget(self.algorithmItem)
+            if self.configuration:
+                self.algorithmItem.setConfiguration(self.configuration)
+            self.verticalLayout.addWidget(self.algorithmItem)
 
         for param in self._alg.parameterDefinitions():
             if param.flags() & QgsProcessingParameterDefinition.FlagAdvanced:
@@ -293,8 +291,15 @@ class ModelerParametersDialog(QDialog):
                 return self.model.parameterDefinition(value.parameterName()).description()
             elif value.source() == QgsProcessingModelChildParameterSource.ChildOutput:
                 alg = self.model.childAlgorithm(value.outputChildId())
-                return self.tr("'{0}' from algorithm '{1}'").format(
-                    alg.algorithm().outputDefinition(value.outputName()).description(), alg.description())
+
+                output_name = alg.algorithm().outputDefinition(value.outputName()).description()
+                # see if this output has been named by the model designer -- if so, we use that friendly name
+                for name, output in alg.modelOutputs().items():
+                    if output.childOutputName() == value.outputName():
+                        output_name = name
+                        break
+
+                return self.tr("'{0}' from algorithm '{1}'").format(output_name, alg.description())
 
         return value
 
